function beePtsAllCams = trackBEEtagForDLT(cam1file, path, tagNumber)

%% Code for auto-tracking bee position relative to flower;

cam2file = strrep(cam1file, 'C001', 'C002');

%% Set up VideoReader objects
mov1 = VideoReader(strcat(path, '/', cam1file));
mov2 = VideoReader(strcat(path, '/', cam2file));

nframes = mov1.NumberOfFrames;
%%
beePtsCam1 = trackTriangleForDLT(mov1, tagNumber);
beePtsCam2 = trackTriangleForDLT(mov2, tagNumber);

%% Create table for output
% Define output prefix
name = mov1.Name;
spl = strsplit(name, '.a');
pref = spl{1};


beePtsAllCams = [beePtsCam1 beePtsCam2];
beePtsAllCams = beePtsAllCams(:,[1 2 7 8 3 4 9 10 5 6 11 12]);
headers = {'pt1_cam1_X', 'pt1_cam1_Y', 'pt1_cam2_X', 'pt1_cam2_Y', 'pt2_cam1_X', 'pt2_cam1_Y', 'pt2_cam2_X', 'pt2_cam2_Y', 'pt3_cam1_X', 'pt3_cam1_Y', 'pt3_cam2_X', 'pt3_cam2_Y'};
%Interpolate data for missing NaNs
beePtsAllCamsRawData = beePtsAllCams;
save(strcat(pref, 'rawTrackingData.mat'), 'beePtsAllCamsRawData');

for i = 1:numel(beePtsAllCams(1,:))
    beePtsAllCams(:,i) = fixgaps(beePtsAllCams(:,i));
end

%% Save output file in DLT ready format
yht = mov1.height; %What is the Y dimension of the cameras?
beePtsAllCams(:,[2 4 6 8 10 12]) = yht - beePtsAllCams(:,[2 4 6 8 10 12]); %Flip these to be in the correct orientation for DLT

suff = 'xypts.csv';
outputName = strcat(pref, suff);
% Save main file
csvwrite_with_headers(outputName, beePtsAllCams, headers);

% Save auxiliary DLT files
suff = 'offsets.csv';
outputName = strcat(pref, suff);
csvwrite_with_headers(outputName, zeros(nframes,2), {'cam1_offset', 'cam2_offset'});

suff = 'xyzpts.csv';
outputName = strcat(pref, suff);
csvwrite_with_headers(outputName, nan(nframes,9), {'pt1_X', 'pt1_Y', 'pt1_Z', 'pt2_X', 'pt2_Y', 'pt2_Z', 'pt3_X', 'pt3_Y', 'pt3_Z'});

suff = 'xyzres.csv';
outputName = strcat(pref, suff);
csvwrite_with_headers(outputName, nan(nframes, 3), {'pt1_dltres', 'pt2_dltres', 'pt3_dltres'});

